==> 0.9.5+1.tar.gz: lib/src/enums/analytics_types.dart <==
import 'package:loglytics/loglytics.dart';

/// Every action or state that's applicable to data from your [Analytics] implementations.
enum AnalyticsTypes {
  event,
  tapped,
  clicked,
  focussed,
  selected,
  connected,
  disconnected,
  viewed,
  hidden,
  opened,
  closed,
  failed,
  succeeded,
  sent,
  received,
  validated,
  invalidated,
  searched,
  liked,
  shared,
  commented,
  input,
  incremented,
  decremented,
  accepted,
  declined,
  alert,
  scrolled,
  started,
  stopped,
  initialised,
  disposed,
  fetched,
  set,
  get,
  foreground,
  background,
  purchased,
  dismissed,
  upgraded,
  downgraded,
  interaction,
  query,
  confirmed,
  canceled,
  created,
  read,
  updated,
  deleted,
  added,
  removed,
  subscribed,
  unsubscribed,
  changed,
  denied,
  skipped,
  checked,
  unchecked,
  attempted,
  reset,
  enabled,
  disabled,
  began,
  ended,
  refreshed,
  generated,
  unsupported,
  invalid,
  valid,
  shown,
  none,
}

/// Used to generate the proper String format when sending analytics to the analytics provider.
extension AnalyticsTypesHelpers on AnalyticsTypes {
  String get name {
    switch (this) {
      case AnalyticsTypes.event:
        return 'event';
      case AnalyticsTypes.tapped:
        return 'tapped';
      case AnalyticsTypes.clicked:
        return 'clicked';
      case AnalyticsTypes.focussed:
        return 'focussed';
      case AnalyticsTypes.selected:
        return 'selected';
      case AnalyticsTypes.connected:
        return 'connected';
      case AnalyticsTypes.disconnected:
        return 'disconnected';
      case AnalyticsTypes.viewed:
        return 'viewed';
      case AnalyticsTypes.hidden:
        return 'hidden';
      case AnalyticsTypes.opened:
        return 'opened';
      case AnalyticsTypes.closed:
        return 'closed';
      case AnalyticsTypes.failed:
        return 'failed';
      case AnalyticsTypes.succeeded:
        return 'succeeded';
      case AnalyticsTypes.sent:
        return 'sent';
      case AnalyticsTypes.received:
        return 'received';
      case AnalyticsTypes.validated:
        return 'validated';
      case AnalyticsTypes.invalidated:
        return 'invalidated';
      case AnalyticsTypes.searched:
        return 'searched';
      case AnalyticsTypes.liked:
        return 'liked';
      case AnalyticsTypes.shared:
        return 'shared';
      case AnalyticsTypes.commented:
        return 'commented';
      case AnalyticsTypes.input:
        return 'input';
      case AnalyticsTypes.incremented:
        return 'incremented';
      case AnalyticsTypes.decremented:
        return 'decremented';
      case AnalyticsTypes.accepted:
        return 'accepted';
      case AnalyticsTypes.declined:
        return 'declined';
      case AnalyticsTypes.alert:
        return 'alert';
      case AnalyticsTypes.scrolled:
        return 'scrolled';
      case AnalyticsTypes.started:
        return 'started';
      case AnalyticsTypes.stopped:
        return 'stopped';
      case AnalyticsTypes.initialised:
        return 'initialised';
      case AnalyticsTypes.disposed:
        return 'disposed';
      case AnalyticsTypes.fetched:
        return 'fetched';
      case AnalyticsTypes.set:
        return 'set';
      case AnalyticsTypes.get:
        return 'get';
      case AnalyticsTypes.foreground:
        return 'foreground';
      case AnalyticsTypes.background:
        return 'background';
      case AnalyticsTypes.purchased:
        return 'purchased';
      case AnalyticsTypes.dismissed:
        return 'dismissed';
      case AnalyticsTypes.upgraded:
        return 'upgraded';
      case AnalyticsTypes.downgraded:
        return 'downgraded';
      case AnalyticsTypes.interaction:
        return 'interaction';
      case AnalyticsTypes.query:
        return 'query';
      case AnalyticsTypes.confirmed:
        return 'confirmed';
      case AnalyticsTypes.canceled:
        return 'canceled';
      case AnalyticsTypes.created:
        return 'created';
      case AnalyticsTypes.read:
        return 'read';
      case AnalyticsTypes.updated:
        return 'updated';
      case AnalyticsTypes.deleted:
        return 'deleted';
      case AnalyticsTypes.added:
        return 'added';
      case AnalyticsTypes.removed:
        return 'removed';
      case AnalyticsTypes.subscribed:
        return 'subscribed';
      case AnalyticsTypes.unsubscribed:
        return 'unsubscribed';
      case AnalyticsTypes.changed:
        return 'changed';
      case AnalyticsTypes.denied:
        return 'denied';
      case AnalyticsTypes.skipped:
        return 'skipped';
      case AnalyticsTypes.checked:
        return 'checked';
      case AnalyticsTypes.unchecked:
        return 'unchecked';
      case AnalyticsTypes.attempted:
        return 'attempted';
      case AnalyticsTypes.reset:
        return 'reset';
      case AnalyticsTypes.enabled:
        return 'enabled';
      case AnalyticsTypes.disabled:
        return 'disabled';
      case AnalyticsTypes.began:
        return 'began';
      case AnalyticsTypes.ended:
        return 'ended';
      case AnalyticsTypes.refreshed:
        return 'refreshed';
      case AnalyticsTypes.generated:
        return 'generated';
      case AnalyticsTypes.unsupported:
        return 'unsupported';
      case AnalyticsTypes.invalid:
        return 'invalid';
      case AnalyticsTypes.valid:
        return 'valid';
      case AnalyticsTypes.shown:
        return 'shown';
      case AnalyticsTypes.none:
        return '';
    }
  }

  /// Used to generate [CustomAnalytic] objects based on [AnalyticsTypes].
  CustomAnalytic toCustomAnalytic(
          {required String subject, Map<String, Object?>? parameters}) =>
      Analytic(subject: subject, type: this, parameters: parameters)
          .toCustomAnalytic;
}

==> 0.12.0+7.tar.gz: lib/src/enums/analytics_types.dart <==
import 'package:loglytics/loglytics.dart';

/// Every action or state that's applicable to data from your [Analytics] implementations.
enum AnalyticsTypes {
  event,
  tapped,
  clicked,
  focussed,
  selected,
  connected,
  disconnected,
  viewed,
  hidden,
  opened,
  closed,
  failed,
  succeeded,
  sent,
  received,
  validated,
  invalidated,
  searched,
  liked,
  shared,
  commented,
  input,
  incremented,
  decremented,
  accepted,
  declined,
  alert,
  scrolled,
  started,
  stopped,
  initialised,
  disposed,
  fetched,
  set,
  get,
  foreground,
  background,
  purchased,
  dismissed,
  upgraded,
  downgraded,
  interaction,
  query,
  confirmed,
  canceled,
  created,
  read,
  updated,
  deleted,
  added,
  removed,
  subscribed,
  unsubscribed,
  changed,
  denied,
  skipped,
  checked,
  unchecked,
  attempted,
  reset,
  enabled,
  disabled,
  began,
  ended,
  refreshed,
  generated,
  unsupported,
  invalid,
  valid,
  shown,
  loaded,
  saved,
  found,
  completed,
  error,
  given,
  notFound,
  taken,
  snoozed,
  verified,
  swiped,
  used,
  filled,
  cleared,
  unverified,
  paused,
  none,
}

/// Used to generate the proper String format when sending analytics to the analytics provider.
extension AnalyticsTypesHelpers on AnalyticsTypes {
  String get value {
    switch (this) {
      case AnalyticsTypes.event:
      case AnalyticsTypes.tapped:
      case AnalyticsTypes.clicked:
      case AnalyticsTypes.focussed:
      case AnalyticsTypes.selected:
      case AnalyticsTypes.connected:
      case AnalyticsTypes.disconnected:
      case AnalyticsTypes.viewed:
      case AnalyticsTypes.hidden:
      case AnalyticsTypes.opened:
      case AnalyticsTypes.closed:
      case AnalyticsTypes.failed:
      case AnalyticsTypes.succeeded:
      case AnalyticsTypes.sent:
      case AnalyticsTypes.received:
      case AnalyticsTypes.validated:
      case AnalyticsTypes.invalidated:
      case AnalyticsTypes.searched:
      case AnalyticsTypes.liked:
      case AnalyticsTypes.shared:
      case AnalyticsTypes.commented:
      case AnalyticsTypes.input:
      case AnalyticsTypes.incremented:
      case AnalyticsTypes.decremented:
      case AnalyticsTypes.accepted:
      case AnalyticsTypes.declined:
      case AnalyticsTypes.alert:
      case AnalyticsTypes.scrolled:
      case AnalyticsTypes.started:
      case AnalyticsTypes.stopped:
      case AnalyticsTypes.initialised:
      case AnalyticsTypes.disposed:
      case AnalyticsTypes.fetched:
      case AnalyticsTypes.set:
      case AnalyticsTypes.get:
      case AnalyticsTypes.foreground:
      case AnalyticsTypes.background:
      case AnalyticsTypes.purchased:
      case AnalyticsTypes.dismissed:
      case AnalyticsTypes.upgraded:
      case AnalyticsTypes.downgraded:
      case AnalyticsTypes.interaction:
      case AnalyticsTypes.query:
      case AnalyticsTypes.confirmed:
      case AnalyticsTypes.canceled:
      case AnalyticsTypes.created:
      case AnalyticsTypes.read:
      case AnalyticsTypes.updated:
      case AnalyticsTypes.deleted:
      case AnalyticsTypes.added:
      case AnalyticsTypes.removed:
      case AnalyticsTypes.subscribed:
      case AnalyticsTypes.unsubscribed:
      case AnalyticsTypes.changed:
      case AnalyticsTypes.denied:
      case AnalyticsTypes.skipped:
      case AnalyticsTypes.checked:
      case AnalyticsTypes.unchecked:
      case AnalyticsTypes.attempted:
      case AnalyticsTypes.reset:
      case AnalyticsTypes.enabled:
      case AnalyticsTypes.disabled:
      case AnalyticsTypes.began:
      case AnalyticsTypes.ended:
      case AnalyticsTypes.refreshed:
      case AnalyticsTypes.generated:
      case AnalyticsTypes.unsupported:
      case AnalyticsTypes.invalid:
      case AnalyticsTypes.valid:
      case AnalyticsTypes.shown:
      case AnalyticsTypes.loaded:
      case AnalyticsTypes.saved:
      case AnalyticsTypes.found:
      case AnalyticsTypes.completed:
      case AnalyticsTypes.error:
      case AnalyticsTypes.taken:
      case AnalyticsTypes.given:
      case AnalyticsTypes.snoozed:
      case AnalyticsTypes.verified:
      case AnalyticsTypes.swiped:
      case AnalyticsTypes.used:
      case AnalyticsTypes.filled:
      case AnalyticsTypes.cleared:
      case AnalyticsTypes.unverified:
      case AnalyticsTypes.paused:
        return name;
      case AnalyticsTypes.notFound:
        return 'not_found';
      case AnalyticsTypes.none:
        return '';
    }
  }

  /// Used to generate [CustomAnalytic] objects based on [AnalyticsTypes].
  CustomAnalytic toCustomAnalytic({
    required String subject,
    Map<String, Object?>? parameters,
  }) =>
      Analytic(subject: subject, type: this, parameters: parameters)
          .toCustomAnalytic;
}
